/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.agent.plugin.fetcher.dtos;

import lombok.Data;

@Data
public class DataConfig {
    private String additionalAttr;
    private String inlongGroupId;
    private String dataName;
    private String inlongStreamId;
    private String deliveryTime;
    private String fieldSplitter;
    private String cycleUnit;
    private String ip;
    private String middlewareType;
    private String mqMasterAddress;
    private String op;
    private String scheduleTime;
    private Integer taskId;
    private String timeOffset;
    private String topic;

    public boolean isValid() {
        return true;
    }
}
